@@ -4,7 +4,6 @@ g++ -DNDEBUG -O3 -Wno-deprecated-declarations $1 $2 $3 \
   src/run/main.cpp \
   src/basic/config.cpp \
   src/util/tinythread.cpp \
-  src/util/compressed_stream.cpp \
   src/basic/score_matrix.cpp \
   src/blast/blast_filter.cpp \
   src/blast/blast_seg.cpp \
@@ -48,7 +47,6 @@ g++ -DNDEBUG -O3 -Wno-deprecated-declarations $1 $2 $3 \
   src/dp/banded_sw.cpp \
   src/data/sorted_list.cpp \
   src/data/seed_set.cpp \
-  src/util/binary_file.cpp \
   src/util/simd.cpp \
   src/output/taxon_format.cpp \
   src/output/view.cpp \
@@ -59,4 +57,23 @@ g++ -DNDEBUG -O3 -Wno-deprecated-declarations $1 $2 $3 \
   src/dp/swipe/banded_3frame_swipe.cpp \
   src/dp/swipe/banded_swipe.cpp \
   src/align/banded_swipe_pipeline.cpp \
+  src/data/ref_dictionary.cpp \
+  src/util/io/compressed_stream.cpp \
+  src/util/io/deserializer.cpp \
+  src/util/io/file_sink.cpp \
+  src/util/io/file_source.cpp \
+  src/util/io/input_file.cpp \
+  src/util/io/input_stream_buffer.cpp \
+  src/util/io/output_file.cpp \
+  src/util/io/output_stream_buffer.cpp \
+  src/util/io/serializer.cpp \
+  src/util/io/temp_file.cpp \
+  src/util/io/text_input_file.cpp \
+  src/data/taxon_list.cpp \
+  src/data/taxonomy_nodes.cpp \
+  src/util/algo/MurmurHash3.cpp \
+  src/search/stage0.cpp \
+  src/util/memory/memory_pool.cpp \
+  src/data/seed_array.cpp \
+  src/output/paf_format.cpp \
 -lz -lpthread -o diamond
