@@ -26,13 +26,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../util/task_queue.h"
 #include "../basic/statistics.h"
 #include "query_mapper.h"
+#include "../data/metadata.h"
 
 using std::vector;
 using std::auto_ptr;
 
 struct Output_writer
 {
-	Output_writer(Output_stream* f) :
+	Output_writer(OutputFile* f) :
 		f_(f)
 	{ }
 	void operator()(TextBuffer &buf)
@@ -41,13 +42,13 @@ struct Output_writer
 		buf.clear();
 	}
 private:
-	Output_stream* const f_;
+	OutputFile* const f_;
 };
 
 template<typename _buffer>
 struct Ring_buffer_sink
 {
-	Ring_buffer_sink(Output_stream *output_file):
+	Ring_buffer_sink(OutputFile *output_file):
 		writer(output_file),
 		queue(config.threads_ * 4, writer)
 	{}
@@ -64,15 +65,15 @@ private:
 	Task_queue<_buffer, Output_writer> queue;
 };
 
-void align_queries(Trace_pt_buffer &trace_pts, Output_stream* output_file);
+void align_queries(Trace_pt_buffer &trace_pts, OutputFile* output_file, const Parameters &params, const Metadata &metadata);
 
 namespace ExtensionPipeline {
 	namespace Greedy {
 		struct Target;
 		struct Pipeline : public QueryMapper
 		{
-			Pipeline(size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end) :
-				QueryMapper(query_id, begin, end)
+			Pipeline(const Parameters &params, size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end) :
+				QueryMapper(params, query_id, begin, end)
 			{}
 			Target& target(size_t i);
 			virtual void run(Statistics &stat);
@@ -82,8 +83,8 @@ namespace ExtensionPipeline {
 	namespace Swipe {
 		struct Pipeline : public QueryMapper
 		{
-			Pipeline(size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end) :
-				QueryMapper(query_id, begin, end)
+			Pipeline(const Parameters &params, size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end) :
+				QueryMapper(params, query_id, begin, end)
 			{}
 			virtual void run(Statistics &stat);
 			virtual ~Pipeline() {}
@@ -93,8 +94,8 @@ namespace ExtensionPipeline {
 		struct Target;
 		struct Pipeline : public QueryMapper
 		{
-			Pipeline(size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end, DpStat &dp_stat) :
-				QueryMapper(query_id, begin, end),
+			Pipeline(const Parameters &params, size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end, DpStat &dp_stat) :
+				QueryMapper(params, query_id, begin, end),
 				dp_stat(dp_stat)
 			{}
 			Target& target(size_t i);
