@@ -28,6 +28,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../util/ptr_vector.h"
 #include "../dp/dp.h"
 #include "../data/reference.h"
+#include "../basic/parameters.h"
+#include "../data/metadata.h"
 
 using std::vector;
 using std::pair;
@@ -56,7 +58,7 @@ struct Target
 	}
 	bool envelopes(const Hsp_traits &t, double p) const;
 	bool is_enveloped(const Target &t, double p) const;
-	bool is_enveloped(Ptr_vector<Target>::const_iterator begin, Ptr_vector<Target>::const_iterator end, double p, int min_score) const;
+	bool is_enveloped(PtrVector<Target>::const_iterator begin, PtrVector<Target>::const_iterator end, double p, int min_score) const;
 	void inner_culling(int cutoff);
 	void apply_filters(int dna_len, int subject_len, const char *query_title, const char *ref_title);
 	unsigned subject_id;
@@ -72,9 +74,9 @@ struct Target
 
 struct QueryMapper
 {
-	QueryMapper(size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end);
+	QueryMapper(const Parameters &params, size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end);
 	void init();
-	bool generate_output(TextBuffer &buffer, Statistics &stat);
+	bool generate_output(TextBuffer &buffer, Statistics &stat, const Metadata &metadata);
 	void rank_targets(double ratio, double factor);
 	void score_only_culling();
 	int raw_score_cutoff() const;
@@ -97,10 +99,12 @@ struct QueryMapper
 	}
 	virtual void run(Statistics &stat) = 0;
 	virtual ~QueryMapper() {}
+
+	const Parameters &parameters;
 	pair<Trace_pt_list::iterator, Trace_pt_list::iterator> source_hits;
 	unsigned query_id, targets_finished, next_target;
 	unsigned source_query_len, unaligned_from;
-	Ptr_vector<Target> targets;
+	PtrVector<Target> targets;
 	vector<Seed_hit> seed_hits;
 	vector<Bias_correction> query_cb;
 	vector<Long_score_profile> profile;
