@@ -26,7 +26,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../util/system.h"
 #include "reduction.h"
 #include "shape_config.h"
-#include "../util/temp_file.h"
+#include "../util/io/temp_file.h"
 #include "../basic/match.h"
 #include "../data/sorted_list.h"
 #include "../basic/translate.h"
@@ -58,7 +58,12 @@ Config::Config(int argc, const char **argv)
 		.add_command("mask", "")
 		.add_command("fastq2fasta", "")
 		.add_command("dbinfo", "Print information about a DIAMOND database file")
-		.add_command("test-extra", "");
+		.add_command("test-extra", "")
+		.add_command("test-io", "")
+		.add_command("db-annot-stats", "")
+		.add_command("read-sim", "")
+		.add_command("info", "")
+		.add_command("seed-stat", "");
 
 	Options_group general("General options");
 	general.add()
@@ -83,6 +88,7 @@ Config::Config(int argc, const char **argv)
 \tsend means End of alignment in subject\n\
 \tqseq means Aligned part of query sequence\n\
 \tsseq means Aligned part of subject sequence\n\
+\tfull_sseq means Full subject sequence\n\
 \tevalue means Expect value\n\
 \tbitscore means Bit score\n\
 \tscore means Raw score\n\
@@ -145,7 +151,8 @@ Config::Config(int argc, const char **argv)
 		("sallseqid", 0, "include all subject ids in DAA file", sallseqid)
 		("no-self-hits", 0, "suppress reporting of identical self hits", no_self_hits)
 		("taxonmap", 0, "protein accession to taxid mapping file", prot_accession2taxid)
-		("taxonnodes", 0, "taxonomy nodes.dmp from NCBI", nodesdmp);
+		("taxonnodes", 0, "taxonomy nodes.dmp from NCBI", nodesdmp)
+		("taxonlist", 0, "restrict search to list of taxon ids (comma-separated)", taxonlist);
 
 	Options_group advanced("Advanced options");
 	advanced.add()
@@ -229,7 +236,17 @@ Config::Config(int argc, const char **argv)
 		("hashed-seeds", 0, "", hashed_seeds)
 		("rank-factor", 0, "", rank_factor, -1.0)
 		("transcript-len-estimate", 0, "", transcript_len_estimate, 1.0)
-		("no-traceback", 0, "", disable_traceback);
+		("no-traceback", 0, "", disable_traceback)
+		("family-counts", 0, "", family_counts_file)
+		("radix-cluster-buffered", 0, "", radix_cluster_buffered)
+		("join-split-size", 0, "", join_split_size, 100000u)
+		("join-split-key-len", 0, "", join_split_key_len, 17u)
+		("radix-bits", 0, "", radix_bits, 8u)
+		("join-ht-factor", 0, "", join_ht_factor, 1.3)
+		("hash-join", 0, "", hash_join)
+		("sort-join", 0, "", sort_join)
+		("simple-freq", 0, "", simple_freq)
+		("freq-treshold", 0, "", freq_treshold);
 		
 	parser.add(general).add(makedb).add(aligner).add(advanced).add(view_options).add(getseq_options).add(hidden_options);
 	parser.store(argc, argv, command);
@@ -345,7 +362,7 @@ Config::Config(int argc, const char **argv)
 		if (query_range_culling && frame_shift == 0)
 			throw std::runtime_error("Query range culling is only supported in frameshift alignment mode (option -F).");
 		if (matrix_file == "")
-			score_matrix = Score_matrix(to_upper_case(matrix), gap_open, gap_extend, reward, penalty, frame_shift);
+			score_matrix = Score_matrix(to_upper_case(matrix), gap_open, gap_extend, frame_shift);
 		else {
 			if (lambda == 0 || K == 0)
 				throw std::runtime_error("Custom scoring matrices require setting the --lambda and --K options.");
