@@ -148,10 +148,22 @@ struct Config
 	bool query_range_culling;
 	double query_range_cover;
 	double transcript_len_estimate;
+	string family_counts_file;
+	string taxonlist;
+	bool radix_cluster_buffered;
+	unsigned join_split_size;
+	unsigned join_split_key_len;
+	unsigned radix_bits;
+	double join_ht_factor;
+	bool hash_join;
+	bool sort_join;
+	bool simple_freq;
+	double freq_treshold;
+	bool use_lazy_dict;
 
 	enum {
 		makedb = 0, blastp = 1, blastx = 2, view = 3, help = 4, version = 5, getseq = 6, benchmark = 7, random_seqs = 8, compare = 9, sort = 10, roc = 11, db_stat = 12, model_sim = 13,
-		match_file_stat = 14, model_seqs = 15, opt = 16, mask = 17, fastq2fasta=18, dbinfo=19, test_extra = 20
+		match_file_stat = 14, model_seqs = 15, opt = 16, mask = 17, fastq2fasta=18, dbinfo=19, test_extra = 20, test_io = 21, db_annot_stats = 22, read_sim = 23, info = 24, seed_stat = 25
 	};
 	unsigned	command;
 
