@@ -196,6 +196,7 @@ struct Hsp
 	bool is_weakly_enveloped_by(std::list<Hsp>::const_iterator begin, std::list<Hsp>::const_iterator end, int cutoff) const;
 	void push_back(const DiagonalSegment &d, const TranslatedSequence &query, const sequence &subject, bool reversed);
 	void push_match(Letter q, Letter s, bool positive);
+	void push_gap(Edit_operation op, int length, const char *subject);
 	void splice(const DiagonalSegment &d0, const DiagonalSegment &d1, const TranslatedSequence &query, const sequence &subject, bool reversed);
 	void set_begin(const DiagonalSegment &d, int dna_len);
 	void set_end(const DiagonalSegment &d, int dna_len);
@@ -223,7 +224,8 @@ struct Hsp_context
 		const char *subject_name,
 		unsigned subject_len,
 		unsigned hit_num,
-		unsigned hsp_num
+		unsigned hsp_num,
+		const sequence &subject_seq
 	) :
 		query(query),
 		query_name(query_name),
@@ -234,7 +236,8 @@ struct Hsp_context
 		subject_len(subject_len),
 		hit_num(hit_num),
 		hsp_num(hsp_num),
-		hsp_(hsp)
+		subject_seq(subject_seq),
+		hsp_(hsp)		
 	{}
 	struct Iterator : public Hsp::Iterator
 	{
@@ -310,7 +313,7 @@ struct Hsp_context
 	{ return hsp_.score; }
 	double evalue() const
 	{
-		return score_matrix.evalue(score(), config.db_size, (unsigned)query.index(0).length());
+		return score_matrix.evalue(score(), (unsigned)query.index(0).length());
 	}
 	double bit_score() const
 	{
@@ -355,6 +358,7 @@ struct Hsp_context
 	const TranslatedSequence query;
 	const char *query_name, *subject_name;
 	const unsigned query_id, subject_id, orig_subject_id, subject_len, hit_num, hsp_num;
+	const sequence subject_seq;
 private:	
 	Hsp &hsp_;
 };
