@@ -21,38 +21,68 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "../util/binary_buffer.h"
 #include "../basic/value.h"
+#include "diagonal_segment.h"
+#include "sequence.h"
 
-typedef enum { op_match=0, op_insertion=1, op_deletion=2, op_substitution=3 } Edit_operation;
+typedef enum { op_match = 0, op_insertion = 1, op_deletion = 2, op_substitution = 3, op_frameshift_forward = 4, op_frameshift_reverse = 5 } Edit_operation;
+
+struct Reversed {};
 
 struct Packed_operation
 {
+	enum { OP_BITS = 2, COUNT_BITS = 8 - OP_BITS, MAX_COUNT = (1 << COUNT_BITS) - 1 };
 	Packed_operation(uint8_t code):
 		code (code)
 	{ }
 	Packed_operation(Edit_operation op, unsigned count):
-		code ((op<<6) | count)
+		code ((op<<COUNT_BITS) | count)
 	{ }
-	Packed_operation(Edit_operation op, Letter v):
-		code ((op<<6) | (int)v)
+	Packed_operation(Edit_operation op, Letter v) :
+		code((op << COUNT_BITS) | (int)v)
 	{ }
 	operator uint8_t() const
 	{ return code; }
 	Edit_operation op() const
-	{ return (Edit_operation)(code>>6); }
+	{
+		uint8_t o = code >> COUNT_BITS;
+		switch (o) {
+		case op_substitution:
+			switch (letter()) {
+			case (Letter)AMINO_ACID_COUNT:
+				return op_frameshift_reverse;
+			case (Letter)(AMINO_ACID_COUNT + 1) :
+				return op_frameshift_forward;
+			default:
+				return op_substitution;
+			}
+		default:
+			return (Edit_operation)o;
+		}
+	}
 	unsigned count() const
 	{
 		switch (op()) {
 		case op_match:
 		case op_insertion:
-			return code & 63;
+			return code & MAX_COUNT;
 		default:
 			return 1;
 		}
 	}
 	Letter letter() const
-	{ return code&63; }
+	{
+		return code&MAX_COUNT;
+	}
 	static Packed_operation terminator()
 	{ return Packed_operation(op_match, 0u); }
+	static Packed_operation frameshift_forward()
+	{
+		return Packed_operation(op_substitution, (unsigned)AMINO_ACID_COUNT + 1);
+	}
+	static Packed_operation frameshift_reverse()
+	{
+		return Packed_operation(op_substitution, (unsigned)AMINO_ACID_COUNT);
+	}
 	uint8_t code;
 };
 
@@ -85,7 +115,7 @@ struct Packed_transcript
 			if(!good())
 				return;
 			op_.op = ptr_->op();
-			if(op_.op == op_deletion || op_.op == op_substitution) {
+			if(op_.op == op_deletion || op_.op == op_substitution || op_.op == op_frameshift_forward || op_.op==op_frameshift_reverse) {
 				op_.letter = ptr_->letter();
 				op_.count = 1;
 			} else {
@@ -101,7 +131,7 @@ struct Packed_transcript
 		Combined_operation op_;
 	};
 
-	void read(Binary_buffer::Iterator &it)
+	void read(BinaryBuffer::Iterator &it)
 	{
 		data_.clear();
 		uint8_t code;
@@ -124,7 +154,11 @@ struct Packed_transcript
 
 	void push_back(Edit_operation op)
 	{
-		if (data_.empty() || data_.back().op() != op || (data_.back().op() == op && data_.back().count() == 63))
+		if (op == op_frameshift_forward)
+			data_.push_back(Packed_operation::frameshift_forward());
+		else if (op == op_frameshift_reverse)
+			data_.push_back(Packed_operation::frameshift_reverse());
+		else if (data_.empty() || data_.back().op() != op || (data_.back().op() == op && data_.back().count() == Packed_operation::MAX_COUNT))
 			data_.push_back(Packed_operation(op, 1u));
 		else
 			++data_.back().code;
@@ -138,15 +172,20 @@ struct Packed_transcript
 	void push_back(Edit_operation op, unsigned count)
 	{
 		while (count > 0) {
-			const unsigned n = std::min(count, 63u);
+			const unsigned n = std::min(count, (unsigned)Packed_operation::MAX_COUNT);
 			data_.push_back(Packed_operation(op, n));
 			count -= n;
 		}
 	}
 
-	void reverse()
+	void reverse(size_t begin = 0)
 	{
-		std::reverse(data_.begin(), data_.end());
+		std::reverse(data_.begin() + begin, data_.end());
+	}
+
+	size_t raw_length() const
+	{
+		return data_.size();
 	}
 
 	void push_terminator()
@@ -159,11 +198,30 @@ struct Packed_transcript
 		data_.clear();
 	}
 
+	void push_back(const sequence &s, const Reversed&)
+	{
+		const int l = (int)s.length();
+		for (int i = l - 1; i >= 0; --i)
+			push_back(op_deletion, s[i]);
+	}
+
+	void push_back(const sequence &s)
+	{
+		const int l = (int)s.length();
+		for (int i = 0; i < l; ++i)
+			push_back(op_deletion, s[i]);
+	}
+
+	void reserve(size_t n)
+	{
+		data_.reserve(n);
+	}
+
 private:
 
 	vector<Packed_operation> data_;
 
-	friend struct Hsp_data;
+	friend struct Hsp;
 
 };
 
