@@ -27,6 +27,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "reduction.h"
 #include "../util/util.h"
 #include "config.h"
+#include "translate.h"
 
 /*struct All_partitions {};
 struct Filter_partition {};
@@ -54,7 +55,7 @@ struct Letter_trail
 	}
 	Letter_trail(const Reduction &reduction)
 	{
-		for (int i = 0; i < 20; ++i)
+		for (size_t i = 0; i < 20; ++i)
 			bucket[i] = reduction(i);
 	}
 	int operator()(char l) const
@@ -84,10 +85,10 @@ struct Letter_trail
 #define OPT_W 7
 typedef Letter_trail Trail[OPT_W];
 
-struct shape
+struct Shape
 {
 
-	shape():
+	Shape():
 		length_ (0),
 		weight_ (0),
 		d_ (0),
@@ -96,7 +97,7 @@ struct shape
 		id_ (0)
 	{ memset(positions_, 0, sizeof(uint32_t)*Const::max_seed_weight); }
 
-	shape(const char *code, unsigned id):
+	Shape(const char *code, unsigned id):
 		weight_ (0),
 		mask_ (0),
 		rev_mask_ (0),
@@ -132,7 +133,8 @@ struct shape
 #endif
 		for (unsigned i = 0; i < weight_; ++i) {
 			Letter l = seq[positions_[i]];
-			if (l == value_traits.mask_char || l == '\xff')
+			if (l == value_traits.mask_char || l == sequence::DELIMITER || l == Translator::STOP)
+			//if (l == value_traits.mask_char || l == sequence::DELIMITER)
 				return false;
 			unsigned r = Reduction::reduction(l);
 #ifdef FREQUENCY_MASKING
@@ -153,7 +155,8 @@ struct shape
 		const uint64_t b = Reduction::reduction.bit_size();
 		for (unsigned i = 0; i < weight_; ++i) {
 			Letter l = seq[positions_[i]];
-			if (l == value_traits.mask_char || l == '\xff')
+			if (l == value_traits.mask_char || l == sequence::DELIMITER || l == Translator::STOP)
+			//if (l == value_traits.mask_char || l == sequence::DELIMITER)
 				return false;
 			unsigned r = Reduction::reduction(l);
 			s <<= b;
@@ -186,7 +189,7 @@ struct shape
 		return true;
 	}
 	
-	friend std::ostream& operator<<(std::ostream&s, const shape &sh)
+	friend std::ostream& operator<<(std::ostream&s, const Shape &sh)
 	{
 		for (unsigned i = 0; i < sh.length_; ++i)
 			s << ((sh.mask_ & (1 << i)) ? '1' : '0');
