@@ -1,6 +1,6 @@
 /****
 DIAMOND protein aligner
-Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
+Copyright (C) 2013-2018 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
@@ -27,18 +27,17 @@ vector<bool> query_aligned;
 Seed_set *query_seeds = 0;
 Hashed_seed_set *query_seeds_hashed = 0;
 
-void write_unaligned(Output_stream *file)
+void write_unaligned(OutputFile *file)
 {
 	const size_t n = query_ids::get().get_length();
-	string s;
+	TextBuffer buf;
 	for (size_t i = 0; i < n; ++i) {
 		if (!query_aligned[i]) {
-			std::stringstream ss;
-			ss << '>' << query_ids::get()[i].c_str() << endl;
-			(align_mode.query_translated ? query_source_seqs::get()[i] : query_seqs::get()[i]).print(ss, input_value_traits);
-			ss << endl;
-			s = ss.str();
-			file->write(s.data(), s.length());
+			buf << '>' << query_ids::get()[i].c_str() << '\n';
+			(align_mode.query_translated ? query_source_seqs::get()[i] : query_seqs::get()[i]).print(buf, input_value_traits);
+			buf << '\n';
+			file->write(buf.get_begin(), buf.size());
+			buf.clear();
 		}
 	}
 }
\ No newline at end of file
