@@ -31,13 +31,13 @@ using std::vector;
 
 typedef vector<Array<unsigned,Const::seedp> > shape_histogram;
 
-struct seedp_range
+struct SeedPartitionRange
 {
-	seedp_range():
+	SeedPartitionRange():
 		begin_ (0),
 		end_ (0)
 	{ }
-	seedp_range(unsigned begin, unsigned end):
+	SeedPartitionRange(unsigned begin, unsigned end):
 		begin_ (begin),
 		end_ (end)
 	{ }
@@ -55,25 +55,25 @@ struct seedp_range
 	{
 		return end_ - begin_;
 	}
-	static seedp_range all()
+	static SeedPartitionRange all()
 	{
-		return seedp_range(0, Const::seedp);
+		return SeedPartitionRange(0, Const::seedp);
 	}
 private:
 	unsigned begin_, end_;
 };
 
-extern seedp_range current_range;
+extern SeedPartitionRange current_range;
 
-inline size_t partition_size(const shape_histogram &hst, unsigned p)
+inline size_t partition_size(const shape_histogram &hst, size_t p)
 {
 	size_t s = 0;
-	for(unsigned i=0;i<hst.size();++i)
+	for (unsigned i = 0; i < hst.size(); ++i)
 		s += hst[i][p];
 	return s;
 }
 
-inline size_t hst_size(const shape_histogram &hst, const seedp_range &range)
+inline size_t hst_size(const shape_histogram &hst, const SeedPartitionRange &range)
 {
 	size_t s = 0;
 	for(unsigned i=range.begin();i<range.end();++i)
@@ -95,7 +95,7 @@ struct Partitioned_histogram
 			data_[s].resize(p_.size() - 1);
 			memset(data_[s].data(), 0, (p_.size() - 1)*sizeof(unsigned)*Const::seedp);
 		}
-		Ptr_vector<Callback> cb;
+		PtrVector<Callback> cb;
 		for (size_t i = 0; i < p_.size() - 1; ++i)
 			cb.push_back(new Callback(i, data_));
 		if (serial)
