@@ -49,15 +49,15 @@ Seed_set::Seed_set(const Sequence_set &seqs, double max_coverage):
 {
 	if (!shapes[0].contiguous())
 		throw std::runtime_error("Contiguous seed required.");
-	Ptr_vector<Seed_set_callback> v;
+	PtrVector<Seed_set_callback> v;
 	v.push_back(new Seed_set_callback(data_, size_t(max_coverage*pow(Reduction::reduction.size(), shapes[0].length_))));
 	seqs.enum_seeds(v, seqs.partition(1), 0, 1, &no_filter);
-	coverage_ = (double)v.back()->coverage / pow(Reduction::reduction.size(), shapes[0].length_);
+	coverage_ = (double)v.back().coverage / pow(Reduction::reduction.size(), shapes[0].length_);
 }
 
 struct Hashed_seed_set_callback
 {
-	Hashed_seed_set_callback(Ptr_vector<PHash_set<Modulo2, No_hash> > &dst):
+	Hashed_seed_set_callback(PtrVector<PHash_set<Modulo2, No_hash> > &dst):
 		dst(dst)
 	{}
 	bool operator()(uint64_t seed, uint64_t pos, uint64_t shape)
@@ -67,14 +67,14 @@ struct Hashed_seed_set_callback
 	}
 	void finish()
 	{}
-	Ptr_vector<PHash_set<Modulo2, No_hash> > &dst;
+	PtrVector<PHash_set<Modulo2, No_hash> > &dst;
 };
 
 Hashed_seed_set::Hashed_seed_set(const Sequence_set &seqs)
 {
 	for (size_t i = 0; i < shapes.count(); ++i)
 		data_.push_back(new PHash_set<Modulo2, No_hash>(next_power_of_2(seqs.letters()*1.25)));
-	Ptr_vector<Hashed_seed_set_callback> v;
+	PtrVector<Hashed_seed_set_callback> v;
 	v.push_back(new Hashed_seed_set_callback(data_));
 	seqs.enum_seeds(v, seqs.partition(1), 0, shapes.count(), &no_filter);
 	for (size_t i = 0; i < shapes.count(); ++i)
