@@ -19,10 +19,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <stdio.h>
 #include <set>
 #include "taxonomy.h"
-#include "../util/compressed_stream.h"
+#include "../util/io/text_input_file.h"
 #include "../basic/config.h"
 #include "../util/merge_sort.h"
 #include "../util/log_stream.h"
+#include "reference.h"
 
 using std::cout;
 using std::endl;
@@ -30,9 +31,10 @@ using std::set;
 
 Taxonomy taxonomy;
 
-string& get_accession(string &t)
+string get_accession(const string &title)
 {
 	size_t i;
+	string t(title);
 	if (t.compare(0, 6, "UniRef") == 0)
 		t.erase(0, t.find('_', 0) + 1);
 	else if ((i = t.find_first_of('|', 0)) != string::npos) {
@@ -52,7 +54,7 @@ void Taxonomy::load()
 {
 	char acc[max_accesion_len + 2];
 	unsigned taxid;
-	Compressed_istream f(config.prot_accession2taxid);
+	TextInputFile f(config.prot_accession2taxid);
 	f.getline();
 	
 	while (!f.eof() && (f.getline(), !f.line.empty())) {
@@ -74,7 +76,7 @@ void Taxonomy::load()
 
 void Taxonomy::load_nodes()
 {
-	Input_stream f(config.nodesdmp);
+	TextInputFile f(config.nodesdmp);
 	unsigned taxid, parent;
 	while (!f.eof() && (f.getline(), !f.line.empty())) {
 		if (sscanf(f.line.c_str(), "%u\t|\t%u", &taxid, &parent) != 2)
@@ -93,6 +95,7 @@ void Taxonomy::init()
 		timer.go("Loading taxonomy");
 		load();
 		timer.finish();
+		log_stream << "Accession mappings = " << accession2taxid_.size() << endl;
 	}
 
 	if (!config.nodesdmp.empty()) {
@@ -102,9 +105,17 @@ void Taxonomy::init()
 	}
 }
 
+vector<string> Taxonomy::Accession::from_title(const char *title)
+{
+	vector<string> t(seq_titles(title));
+	for (vector<string>::iterator i = t.begin(); i < t.end(); ++i)
+		*i = get_accession(blast_id(*i));
+	return t;
+}
+
 void Taxonomy::get_taxids(const char *id, set<unsigned> &taxons) const
 {
-	const vector<string> t(tokenize(id, "\1"));
+	const vector<string> t(seq_titles(id));
 	for (vector<string>::const_iterator i = t.begin(); i < t.end(); ++i) {
 		const unsigned id = get(Taxonomy::Accession(*i));
 		if(id != 0)
