@@ -23,10 +23,18 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../basic/const.h"
 #include "../util/util.h"
 
+using std::vector;
 using std::pair;
 using std::string;
 
-string& get_accession(string &t);
+string get_accession(const string &t);
+
+struct AccessionLengthError : public std::runtime_error
+{
+	AccessionLengthError() :
+		std::runtime_error("Accession exceeds maximum length.")
+	{ }
+};
 
 struct Taxonomy
 {
@@ -35,15 +43,17 @@ struct Taxonomy
 	{
 		Accession(const char *s)
 		{
+			if (strlen(s) > max_accesion_len)
+				throw AccessionLengthError();
 			strncpy(this->s, s, max_accesion_len);
 		}
 		Accession(const string &s)
 		{
-			string t(get_title(s));
+			string t(blast_id(s));
 			get_accession(t);
 			if (t.length() > max_accesion_len) {
 				//this->s[0] = 0;
-				throw std::runtime_error("Accession exceeds maximum length.");
+				throw AccessionLengthError();
 			}
 			else
 				strncpy(this->s, t.c_str(), max_accesion_len);
@@ -63,6 +73,7 @@ struct Taxonomy
 			}
 			return strncmp(s, y.s, n) == 0;
 		}
+		static vector<string> from_title(const char *title);
 		friend std::ostream& operator<<(std::ostream &str, const Accession &x)
 		{
 			for (int i = 0; i < max_accesion_len && x.s[i] != 0; ++i)
@@ -88,7 +99,7 @@ struct Taxonomy
 
 	unsigned get_parent(unsigned taxid) const
 	{
-		if (parent_.size() <= taxid)
+		if (taxid >= parent_.size())
 			throw std::runtime_error(string("No taxonomy node found for taxon id ") + to_string(taxid));
 		return parent_[taxid];
 	}
@@ -100,6 +111,8 @@ private:
 	std::vector<std::pair<Accession, unsigned> > accession2taxid_;
 	std::vector<unsigned> parent_;
 
+	friend struct TaxonomyNodes;
+
 };
 
 extern Taxonomy taxonomy;
\ No newline at end of file
