@@ -1,6 +1,6 @@
 /****
 DIAMOND protein aligner
-Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
+Copyright (C) 2013-2018 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
@@ -69,7 +69,8 @@ const char* Blast_tab_format::field_str[] = {
 	"qcovus",		// 44 means Query Coverage Per Unique Subject(blastn only)
 	"qtitle",		// 45 means Query title
 	"swdiff",		// 46
-	"time"			// 47
+	"time", 		// 47
+	"full_sseq"		// 48
 };
 
 Blast_tab_format::Blast_tab_format() :
@@ -85,27 +86,22 @@ Blast_tab_format::Blast_tab_format() :
 		int j = get_idx(field_str, sizeof(field_str) / sizeof(field_str[0]), i->c_str());
 		if(j == -1)
 			throw std::runtime_error(string("Invalid output field: ") + *i);
-		if (j == 34 && config.prot_accession2taxid.empty())
-			throw std::runtime_error("staxids output field requires setting the --taxonmap parameter.");
+		if (j == 34)
+			needs_taxon_id_lists = true;
 		fields.push_back(j);
 		if (j == 6 || j == 39 || j == 40 || j == 34)
 			config.salltitles = true;
+		if (j == 48)
+			config.use_lazy_dict = true;
 	}
 }
 
-void print_staxids(TextBuffer &out, const char *id)
+void print_staxids(TextBuffer &out, unsigned subject_global_id, const Metadata &metadata)
 {
-	std::set<unsigned> taxons;
-	taxonomy.get_taxids(id, taxons);
-	if (taxons.empty())
-		return;
-	std::set<unsigned>::const_iterator i = taxons.begin();
-	out << *(i++);
-	for (; i != taxons.end(); ++i)
-		out << ';' << *i;
+	out.print((*metadata.taxon_list)[subject_global_id], ';');
 }
 
-void Blast_tab_format::print_match(const Hsp_context& r, TextBuffer &out)
+void Blast_tab_format::print_match(const Hsp_context& r, const Metadata &metadata, TextBuffer &out)
 {
 	for (vector<unsigned>::const_iterator i = fields.begin(); i != fields.end(); ++i) {
 		switch (*i) {
@@ -223,7 +219,7 @@ void Blast_tab_format::print_match(const Hsp_context& r, TextBuffer &out)
 		}
 			break;
 		case 34:
-			print_staxids(out, r.subject_name);
+			print_staxids(out, r.orig_subject_id, metadata);
 			break;
 		case 39:
 			print_title(out, r.subject_name, true, false, "<>");
@@ -243,6 +239,9 @@ void Blast_tab_format::print_match(const Hsp_context& r, TextBuffer &out)
 		case 47:
 			out << r.time();
 			break;
+		case 48:
+			out << r.subject_seq;
+			break;
 		default:
 			throw std::runtime_error("Invalid output field");
 		}
@@ -270,6 +269,7 @@ void Blast_tab_format::print_query_intro(size_t query_num, const char *query_nam
 			case 33:
 			case 39:
 			case 40:
+			case 48:
 				out << '*';
 				break;
 			case 12:
