@@ -17,19 +17,21 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
 #include "output.h"
-#include "../util/temp_file.h"
+#include "../util/io/temp_file.h"
 #include "../data/queries.h"
 #include "../output/daa_write.h"
 #include "output_format.h"
 #include "../align/query_mapper.h"
 #include "target_culling.h"
+#include "../data/ref_dictionary.h"
+#include "../util/log_stream.h"
 
 struct JoinFetcher
 {
-	static void init(const vector<Temp_file> &tmp_file)
+	static void init(const PtrVector<TempFile> &tmp_file)
 	{
-		for (vector<Temp_file>::const_iterator i = tmp_file.begin(); i != tmp_file.end(); ++i) {
-			files.push_back(Input_stream(*i));
+		for (PtrVector<TempFile>::const_iterator i = tmp_file.begin(); i != tmp_file.end(); ++i) {
+			files.push_back(new InputFile(**i));
 			query_ids.push_back(0);
 			files.back().read(&query_ids.back(), 1);
 		}
@@ -37,8 +39,8 @@ struct JoinFetcher
 	}
 	static void finish()
 	{
-		for (vector<Input_stream>::iterator i = files.begin(); i != files.end(); ++i)
-			i->close_and_delete();
+		for (PtrVector<InputFile>::iterator i = files.begin(); i != files.end(); ++i)
+			(*i)->close_and_delete();
 		files.clear();
 		query_ids.clear();
 	}
@@ -70,20 +72,20 @@ struct JoinFetcher
 				buf[i].clear();
 		return next() != IntermediateRecord::finished;
 	}
-	static vector<Input_stream> files;
+	static PtrVector<InputFile> files;
 	static vector<unsigned> query_ids;
 	static unsigned query_last;
 	vector<BinaryBuffer> buf;
 	unsigned query_id, unaligned_from;
 };
 
-vector<Input_stream> JoinFetcher::files;
+PtrVector<InputFile> JoinFetcher::files;
 vector<unsigned> JoinFetcher::query_ids;
 unsigned JoinFetcher::query_last;
 
 struct JoinWriter
 {
-	JoinWriter(Output_stream &f):
+	JoinWriter(OutputFile &f):
 		f_(f)
 	{}
 	void operator()(TextBuffer& buf)
@@ -91,7 +93,7 @@ struct JoinWriter
 		f_.write(buf.get_begin(), buf.size());
 		buf.clear();
 	}
-	Output_stream &f_;
+	OutputFile &f_;
 };
 
 struct Join_record
@@ -164,8 +166,9 @@ struct BlockJoiner
 	vector<BinaryBuffer::Iterator> it;
 };
 
-void join_query(vector<BinaryBuffer> &buf, TextBuffer &out, Statistics &statistics, unsigned query, const char *query_name, unsigned query_source_len, Output_format &f)
+void join_query(vector<BinaryBuffer> &buf, TextBuffer &out, Statistics &statistics, unsigned query, const char *query_name, unsigned query_source_len, Output_format &f, const Metadata &metadata)
 {
+	const ReferenceDictionary& dict = ReferenceDictionary::get();
 	TranslatedSequence query_seq(get_translated_query(query));
 	BlockJoiner joiner(buf);
 	vector<IntermediateRecord> target_hsp;
@@ -190,12 +193,14 @@ void join_query(vector<BinaryBuffer> &buf, TextBuffer &out, Statistics &statisti
 					query,
 					query_seq,
 					query_name,
-					ref_map.check_id(i->subject_id),
-					ref_map.original_id(i->subject_id),
-					ref_map.name(i->subject_id),
-					ref_map.length(i->subject_id),
+					dict.check_id(i->subject_id),
+					dict.database_id(i->subject_id),
+					dict.name(i->subject_id),
+					dict.length(i->subject_id),
 					n_target_seq,
-					hsp_num).parse(), out);
+					hsp_num,
+					config.use_lazy_dict ? dict.seq(i->subject_id) : sequence()
+					).parse(), metadata, out);
 			}
 		}
 
@@ -206,7 +211,7 @@ void join_query(vector<BinaryBuffer> &buf, TextBuffer &out, Statistics &statisti
 	}
 }
 
-void join_worker(Task_queue<TextBuffer, JoinWriter> *queue)
+void join_worker(Task_queue<TextBuffer, JoinWriter> *queue, const Parameters *params, const Metadata *metadata)
 {
 	JoinFetcher fetcher;
 	size_t n;
@@ -224,7 +229,7 @@ void join_worker(Task_queue<TextBuffer, JoinWriter> *queue)
 		if (*output_format != Output_format::daa && config.report_unaligned != 0) {
 			for (unsigned i = fetcher.unaligned_from; i < fetcher.query_id; ++i) {
 				output_format->print_query_intro(i, query_ids::get()[i].c_str(), get_source_query_len(i), *out, true);
-				output_format->print_query_epilog(*out, query_ids::get()[i].c_str(), true);
+				output_format->print_query_epilog(*out, query_ids::get()[i].c_str(), true, *params);
 			}
 		}
 
@@ -235,12 +240,12 @@ void join_worker(Task_queue<TextBuffer, JoinWriter> *queue)
 		else
 			f->print_query_intro(fetcher.query_id, query_name, (unsigned)query_seq.length(), *out, false);
 
-		join_query(fetcher.buf, *out, stat, fetcher.query_id, query_name, (unsigned)query_seq.length(), *f);
+		join_query(fetcher.buf, *out, stat, fetcher.query_id, query_name, (unsigned)query_seq.length(), *f, *metadata);
 
 		if (*f == Output_format::daa)
 			finish_daa_query_record(*out, seek_pos);
 		else
-			f->print_query_epilog(*out, query_name, false);
+			f->print_query_epilog(*out, query_name, false, *params);
 
 		queue->push(n);
 	}
@@ -248,23 +253,32 @@ void join_worker(Task_queue<TextBuffer, JoinWriter> *queue)
 	statistics += stat;
 }
 
-void join_blocks(unsigned ref_blocks, Output_stream &master_out, const vector<Temp_file> &tmp_file)
+void join_blocks(unsigned ref_blocks, OutputFile &master_out, const PtrVector<TempFile> &tmp_file, const Parameters &params, const Metadata &metadata, DatabaseFile &db_file)
 {
-	ref_map.init_rev_map();
+	//ReferenceDictionary::get().init_rev_map();
+	task_timer timer("Building reference dictionary", 3);
+	if (config.use_lazy_dict)
+		ReferenceDictionary::get().build_lazy_dict(db_file);
+	timer.go("Joining output blocks");
 	JoinFetcher::init(tmp_file);
 	JoinWriter writer(master_out);
 	Task_queue<TextBuffer, JoinWriter> queue(3 * config.threads_, writer);
 	Thread_pool threads;
 	for (unsigned i = 0; i < config.threads_; ++i)
-		threads.push_back(launch_thread(join_worker, &queue));
+		threads.push_back(launch_thread(join_worker, &queue, &params, &metadata));
 	threads.join_all();
 	JoinFetcher::finish();
 	if (*output_format != Output_format::daa && config.report_unaligned != 0) {
 		TextBuffer out;
 		for (unsigned i = JoinFetcher::query_last + 1; i < query_ids::get().get_length(); ++i) {
 			output_format->print_query_intro(i, query_ids::get()[i].c_str(), get_source_query_len(i), out, true);
-			output_format->print_query_epilog(out, query_ids::get()[i].c_str(), true);
+			output_format->print_query_epilog(out, query_ids::get()[i].c_str(), true, params);
 		}
 		writer(out);
 	}
+	if (config.use_lazy_dict) {
+		timer.go("Deallocating dictionary");
+		delete ref_seqs::data_;
+		ref_seqs::data_ = NULL;
+	}
 }
\ No newline at end of file
