@@ -19,11 +19,15 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef OUTPUT_H_
 #define OUTPUT_H_
 
-#include "../util/binary_file.h"
+#include <map>
+#include "../util/io/output_file.h"
 #include "../basic/packed_transcript.h"
 #include "../util/text_buffer.h"
-#include "../align/align_struct.h"
 #include "../data/reference.h"
+#include "../basic/match.h"
+#include "../data/ref_dictionary.h"
+#include "../basic/parameters.h"
+#include "../data/metadata.h"
 
 inline unsigned get_length_flag(unsigned x)
 {
@@ -39,7 +43,7 @@ inline unsigned get_rev_flag(unsigned frame)
 	return frame > 2 ? 1 : 0;
 }
 
-inline uint8_t get_segment_flag(const Hsp_data &match)
+inline uint8_t get_segment_flag(const Hsp &match)
 {
 	unsigned rev = get_rev_flag(match.frame);
 	return (uint8_t)(get_length_flag(match.score)
@@ -57,49 +61,93 @@ inline uint8_t get_segment_flag(const Hsp_context &match)
 		| rev << 6);
 }
 
-struct Intermediate_record
+struct IntermediateRecord
 {
-	void read(Binary_buffer::Iterator &f)
+	void read(BinaryBuffer::Iterator &f)
 	{
 		f.read(subject_id);
 		f.read(flag);
 		f.read_packed(flag & 3, score);
 		f.read_packed((flag >> 2) & 3, query_begin);
+		f.read_varint(query_end);
 		f.read_packed((flag >> 4) & 3, subject_begin);
 		transcript.read(f);
 	}
-	static size_t write_query_intro(Text_buffer &buf, unsigned query_id)
+	interval absolute_query_range() const
+	{
+		if (query_begin < query_end)
+			return interval(query_begin, query_end + 1);
+		else
+			return interval(query_end, query_begin + 1);
+	}
+	static size_t write_query_intro(TextBuffer &buf, unsigned query_id)
 	{
 		size_t seek_pos = buf.size();
 		buf.write(query_id).write(0u);
 		return seek_pos;
 	}
-	static void finish_query(Text_buffer &buf, size_t seek_pos)
+	static void finish_query(TextBuffer &buf, size_t seek_pos)
 	{
 		*(unsigned*)(&buf[seek_pos + sizeof(unsigned)]) = safe_cast<unsigned>(buf.size() - seek_pos - sizeof(unsigned) * 2);
 	}
-	static void write(Text_buffer &buf, const Hsp_data &match, unsigned query_id, unsigned subject_id)
+	static void write(TextBuffer &buf, const Hsp &match, unsigned query_id, size_t subject_id)
 	{
-		buf.write(ref_map.get(current_ref_block, subject_id))
+		const interval oriented_range (match.oriented_range());
+		buf.write(ReferenceDictionary::get().get(current_ref_block, subject_id))
 			.write(get_segment_flag(match))
 			.write_packed(match.score)
-			.write_packed(match.oriented_range().begin_)
+			.write_packed(oriented_range.begin_)
+			.write_varint(oriented_range.end_)
 			.write_packed(match.subject_range.begin_)
 			<< match.transcript.data();
 	}
-	static void finish_file(Output_stream &f)
+	static void finish_file(OutputFile &f)
 	{
 		unsigned x = finished;
 		f.write(&x, 1);
 	}
 	enum { finished = 0xffffffffu };
-	uint32_t query_id, subject_id, score, query_begin, subject_begin;
+	uint32_t query_id, subject_id, score, query_begin, subject_begin, query_end;
 	uint8_t flag;
 	Packed_transcript transcript;
 };
 
-#ifndef ST_JOIN
-void join_blocks(unsigned ref_blocks, Output_stream &master_out, const vector<Temp_file> &tmp_file);
-#endif
+void join_blocks(unsigned ref_blocks, OutputFile &master_out, const PtrVector<TempFile> &tmp_file, const Parameters &params, const Metadata &metadata, DatabaseFile &db_file);
+
+struct OutputSink
+{
+	OutputSink(size_t begin, OutputFile *f) :
+		f_(f),
+		next_(begin),
+		size_(0),
+		max_size_(0)
+	{}
+	void push(size_t n, TextBuffer *buf);
+	size_t size() const
+	{
+		return size_;
+	}
+	size_t max_size() const
+	{
+		return max_size_;
+	}
+	static OutputSink& get()
+	{
+		return *instance;
+	}
+	size_t next() const
+	{
+		return next_;
+	}
+	static auto_ptr<OutputSink> instance;
+private:
+	void flush(TextBuffer *buf);
+	tthread::mutex mtx_;
+	OutputFile* const f_;
+	std::map<size_t, TextBuffer*> backlog_;
+	size_t next_, size_, max_size_;
+};
+
+void heartbeat_worker(size_t qend);
 
 #endif
\ No newline at end of file
