@@ -18,7 +18,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "output_format.h"
 
-void print_md(const Hsp_context &r, Text_buffer &buf)
+void print_md(const Hsp_context &r, TextBuffer &buf)
 {
 	unsigned matches = 0, del = 0;
 	for (Packed_transcript::Const_iterator i = r.begin_old(); i.good(); ++i) {
@@ -27,8 +27,6 @@ void print_md(const Hsp_context &r, Text_buffer &buf)
 			del = 0;
 			matches += i->count;
 			break;
-		case op_insertion:
-			break;
 		case op_substitution:
 			if (matches > 0) {
 				buf << matches;
@@ -49,16 +47,18 @@ void print_md(const Hsp_context &r, Text_buffer &buf)
 				buf << '^';
 			buf << value_traits.alphabet[(long)i->letter];
 			++del;
+		default:
+			break;
 		}
 	}
 	if (matches > 0)
 		buf << matches;
 }
 
-void print_cigar(const Hsp_context &r, Text_buffer &buf)
+void print_cigar(const Hsp_context &r, TextBuffer &buf)
 {
-	static const unsigned map[] = { 0, 1, 2, 0 };
-	static const char letter[] = { 'M', 'I', 'D' };
+	static const unsigned map[] = { 0, 1, 2, 0, 3, 4 };
+	static const char letter[] = { 'M', 'I', 'D', '\\', '/' };
 	unsigned n = 0, op = 0;
 	for (Packed_transcript::Const_iterator i = r.begin_old(); i.good(); ++i) {
 		if (map[i->op] == op)
@@ -74,7 +74,7 @@ void print_cigar(const Hsp_context &r, Text_buffer &buf)
 		buf << n << letter[op];
 }
 
-void Sam_format::print_query_intro(size_t query_num, const char *query_name, unsigned query_len, Text_buffer &out, bool unaligned) const
+void Sam_format::print_query_intro(size_t query_num, const char *query_name, unsigned query_len, TextBuffer &out, bool unaligned) const
 {
 	if (unaligned) {
 		out.write_until(query_name, Const::id_delimiters);
@@ -82,7 +82,7 @@ void Sam_format::print_query_intro(size_t query_num, const char *query_name, uns
 	}
 }
 
-void Sam_format::print_match(const Hsp_context& r, Text_buffer &out) const
+void Sam_format::print_match(const Hsp_context& r, const Metadata &metadata, TextBuffer &out)
 {
 	out.write_until(r.query_name, Const::id_delimiters);
 	out << '\t' << '0' << '\t';
@@ -100,17 +100,17 @@ void Sam_format::print_match(const Hsp_context& r, Text_buffer &out) const
 		<< '*' << '\t'
 		<< '0' << '\t'
 		<< '0' << '\t'
-		<< sequence(&r.query[r.query_range().begin_], r.query_range().length()) << '\t'
+		<< sequence(&r.query.index(r.frame())[r.query_range().begin_], r.query_range().length()) << '\t'
 		<< '*' << '\t'
 		<< "AS:i:" << (uint32_t)score_matrix.bitscore(r.score()) << '\t'
 		<< "NM:i:" << r.length() - r.identities() << '\t'
 		<< "ZL:i:" << r.subject_len << '\t'
 		<< "ZR:i:" << r.score() << '\t'
 		<< "ZE:f:";
-	out.print_e(score_matrix.evalue(r.score(), config.db_size, (unsigned)r.query.length()));
+	out.print_e(score_matrix.evalue(r.score(), (unsigned)r.query.index(r.frame()).length()));
 	out << '\t'
 		<< "ZI:i:" << r.identities() * 100 / r.length() << '\t'
-		<< "ZF:i:" << blast_frame(r.frame()) << '\t'
+		<< "ZF:i:" << Frame(r.frame()).signed_frame() << '\t'
 		<< "ZS:i:" << r.oriented_query_range().begin_ + 1 << '\t'
 		<< "MD:Z:";
 
@@ -118,7 +118,7 @@ void Sam_format::print_match(const Hsp_context& r, Text_buffer &out) const
 	out << '\n';
 }
 
-void Sam_format::print_header(Output_stream &f, int mode, const char *matrix, int gap_open, int gap_extend, double evalue, const char *first_query_name, unsigned first_query_len) const
+void Sam_format::print_header(OutputFile &f, int mode, const char *matrix, int gap_open, int gap_extend, double evalue, const char *first_query_name, unsigned first_query_len) const
 {
 	static const char* mode_str[] = { 0, 0, "BlastP", "BlastX", "BlastN" };
 	string line = string("@HD\tVN:1.5\tSO:query\n\
