@@ -22,16 +22,15 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 using std::set;
 
-void Taxon_format::print_match(const Hsp_context &r, TextBuffer &out)
+void Taxon_format::print_match(const Hsp_context &r, const Metadata &metadata, TextBuffer &out)
 {
-	set<unsigned> taxons;
-	taxonomy.get_taxids(r.subject_name, taxons);
+	const vector<unsigned> taxons((*metadata.taxon_list)[r.orig_subject_id]);
 	if (taxons.empty())
 		return;
 	evalue = std::min(evalue, r.evalue());
 	try {
-		for (set<unsigned>::const_iterator i = taxons.begin(); i != taxons.end(); ++i)
-			taxid = taxonomy.get_lca(taxid, *i);
+		for (vector<unsigned>::const_iterator i = taxons.begin(); i != taxons.end(); ++i)
+			taxid = metadata.taxon_nodes->get_lca(taxid, *i);
 	}
 	catch (std::exception &) {
 		std::cerr << "Query=" << r.query_name << endl << "Subject=" << r.subject_name << endl;
@@ -39,7 +38,7 @@ void Taxon_format::print_match(const Hsp_context &r, TextBuffer &out)
 	}
 }
 
-void Taxon_format::print_query_epilog(TextBuffer &out, const char *query_title, bool unaligned) const
+void Taxon_format::print_query_epilog(TextBuffer &out, const char *query_title, bool unaligned, const Parameters &params) const
 {
 	out.write_until(query_title, Const::id_delimiters);
 	out << '\t' << taxid << '\t';
