@@ -35,6 +35,11 @@ void make_db();
 void db_info();
 void test_main();
 void benchmark_sw();
+void test_io();
+void db_annot_stats();
+void read_sim();
+void info();
+void seed_stat();
 
 int main(int ac, const char* av[])
 {
@@ -98,6 +103,18 @@ int main(int ac, const char* av[])
 		case Config::dbinfo:
 			db_info();
 			break;
+		case Config::test_io:
+			test_io();
+			break;
+		case Config::db_annot_stats:
+			db_annot_stats();
+			break;
+		case Config::read_sim:
+			read_sim();
+			break;
+		case Config::info:
+			info();
+			break;
 #ifdef EXTRA
 		case Config::test_extra:
 			test_main();
@@ -105,6 +122,9 @@ int main(int ac, const char* av[])
 		case Config::benchmark:
 			benchmark_sw();
 			break;
+		case Config::seed_stat:
+			seed_stat();
+			break;
 #endif
 		default:
 			return 1;
