@@ -17,7 +17,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <time.h>
 #include <set>
+#include <iostream>
 #include "tools.h"
 #include "../basic/config.h"
 #include "../data/sequence_set.h"
@@ -28,22 +31,26 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../extra/match_file.h"
 #include "../basic/masking.h"
 
+using std::cout;
+using std::endl;
+
 void get_seq()
 {
-	Database_file db_file;
+	DatabaseFile db_file;
 	db_file.get_seq();
 }
 
 void random_seqs()
 {
-	Database_file db_file;
-	db_file.load_seqs();
+	DatabaseFile db_file;
+	vector<unsigned> v;
+	db_file.load_seqs(v, std::numeric_limits<size_t>::max(), true);
 	cout << "Sequences = " << ref_seqs::get().get_length() << endl;
 	std::set<unsigned> n;
 	const size_t count = atoi(config.seq_no[0].c_str());
 	while (n.size() < count)
 		n.insert((rand()*RAND_MAX + rand()) % ref_seqs::get().get_length());
-	Output_stream out(config.output_file);
+	OutputFile out(config.output_file);
 	unsigned j = 0;
 	
 	std::string s;
@@ -51,7 +58,7 @@ void random_seqs()
 		std::stringstream ss;
 		ss << '>' << j++ << endl;
 		if (config.reverse)
-			ref_seqs::get()[*i].print(ss, value_traits, sequence::Reversed());
+			; // ref_seqs::get()[*i].print(ss, value_traits, sequence::Reversed());
 		else
 			ss << ref_seqs::get()[*i];
 		ss << endl;
@@ -63,7 +70,7 @@ void random_seqs()
 
 void sort_file()
 {
-	Input_stream f(config.query_file);
+	TextInputFile f(config.query_file);
 	vector<Pair<unsigned, string> > data;
 	while (f.getline(), !f.eof()) {
 		unsigned query;
@@ -78,8 +85,9 @@ void sort_file()
 
 void db_stat()
 {
-	Database_file db_file;
-	db_file.load_seqs();
+	DatabaseFile db_file;
+	vector<unsigned> v;
+	db_file.load_seqs(v, std::numeric_limits<size_t>::max(), true);
 	cout << "Sequences = " << ref_seqs::get().get_length() << endl;
 
 	size_t letters = 0;
@@ -110,7 +118,7 @@ void match_file_stat()
 
 void run_masker()
 {
-	Input_stream f(config.query_file);
+	TextInputFile f(config.query_file);
 	vector<Letter> seq, seq2;
 	vector<char> id;
 	const FASTA_format format;
@@ -131,7 +139,7 @@ void run_masker()
 
 void fastq2fasta()
 {
-	auto_ptr<Input_stream> f(Compressed_istream::auto_detect(config.query_file));
+	auto_ptr<TextInputFile> f(new TextInputFile(config.query_file));
 	vector<Letter> seq;
 	vector<char> id;
 	const FASTQ_format format;
@@ -142,4 +150,71 @@ void fastq2fasta()
 		cout << sequence(seq.data(), seq.size()) << endl;
 		++n;
 	}
+}
+
+void test_io()
+{
+	const size_t buf_size = 1;
+	Timer t;
+	t.start();
+	/*InputFile f(config.query_file, InputFile::BUFFERED);
+	char buf[buf_size];	
+	size_t total = 0;
+	while (f.read(buf, buf_size) == buf_size)
+		total += buf_size;*/
+
+	DatabaseFile db;
+	vector<unsigned> v;
+	db.load_seqs(v, std::numeric_limits<size_t>::max(), true);
+
+	size_t total = ref_seqs::get().raw_len() + ref_ids::get().raw_len();
+	cout << "MBytes/sec = " << total / 1e6 / t.getElapsedTime() << endl;
+	cout << "Time = " << t.getElapsedTime() << "s" << endl;
+}
+
+void read_sim()
+{
+	const double ID = 0.35;
+	srand((unsigned)time(0));
+	TextInputFile in(config.query_file);
+	OutputFile out(config.output_file);
+	FASTA_format format;
+	vector<char> id, seq;
+	input_value_traits = nucleotide_traits;
+	TextBuffer buf;
+	while (format.get_seq(id, seq, in)) {
+		buf << '>' << id << '\n';
+		for (size_t i = 0; i < seq.size(); ++i) {
+			if ((double)rand() / RAND_MAX <= ID)
+				buf << nucleotide_traits.alphabet[(size_t)seq[i]];
+			else
+				buf << nucleotide_traits.alphabet[rand() % 4];
+		}
+		buf << '\n';
+		out.write(buf.get_begin(), buf.size());
+		buf.clear();
+	}
+	out.close();
+}
+
+void info()
+{
+	vector<string> arch_flags;
+#ifdef __SSE2__
+	arch_flags.push_back("sse2");
+#endif
+#ifdef __SSE3__
+	arch_flags.push_back("sse3");
+#endif
+#ifdef __SSSE3__
+	arch_flags.push_back("ssse3");
+#endif
+#ifdef __POPCNT__
+	arch_flags.push_back("popcnt");
+#endif
+
+	cout << "Architecture flags: ";
+	for (vector<string>::const_iterator i = arch_flags.begin(); i != arch_flags.end(); ++i)
+		cout << *i << ' ';
+	cout << endl;
 }
\ No newline at end of file
