@@ -19,6 +19,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "align_range.h"
 #include "hit_filter.h"
 #include "sse_dist.h"
+#include "seed_complexity.h"
 
 Trace_pt_buffer* Trace_pt_buffer::instance;
 
@@ -135,6 +136,10 @@ void load_fps(const sorted_list::const_iterator &i, vector<Finger_print> &v, con
 
 void Seed_filter::run(const sorted_list::const_iterator &q, const sorted_list::const_iterator &s)
 {
+	if (config.simple_freq && !SeedComplexity::complex(query_seqs::get().data(q[0]), shapes[sid])) {
+		stats.inc(Statistics::LOW_COMPLEXITY_SEEDS);
+		return;
+	}
 	hits.clear();
 	load_fps(q, vq, *query_seqs::data_);
 	load_fps(s, vs, *ref_seqs::data_);
@@ -142,4 +147,24 @@ void Seed_filter::run(const sorted_list::const_iterator &q, const sorted_list::c
 	std::sort(hits.begin(), hits.end());
 	stats.inc(Statistics::TENTATIVE_MATCHES1, hits.size());
 	stage2_search(q, s, hits, stats, out, sid);
+}
+
+void load_fps(const Packed_loc *p, size_t n, vector<Finger_print> &v, const Sequence_set &seqs)
+{
+	v.clear();
+	v.reserve(n);
+	const Packed_loc *end = p + n;
+	for (; p < end; ++p)
+		v.push_back(Finger_print(seqs.data(*p)));
+}
+
+void Seed_filter::run(const Packed_loc *q, size_t nq, const Packed_loc *s, size_t ns)
+{
+	hits.clear();
+	load_fps(q, nq, vq, *query_seqs::data_);
+	load_fps(s, ns, vs, *ref_seqs::data_);
+	tiled_search(vq.begin(), vq.end(), vs.begin(), vs.end(), Range_ref(vq.begin(), vs.begin()), 0);
+	std::sort(hits.begin(), hits.end());
+	stats.inc(Statistics::TENTATIVE_MATCHES1, hits.size());
+	stage2_search(q, s, hits, stats, out, sid);
 }
\ No newline at end of file
