@@ -19,6 +19,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "align_range.h"
 #include "../data/reference.h"
 #include "../basic/config.h"
+#include "seed_complexity.h"
+#include "search.h"
+
+double SeedComplexity::prob_[AMINO_ACID_COUNT];
+const double SINGLE_INDEXED_SEED_SPACE_MAX_COVERAGE = 0.15;
 
 void setup_search_cont()
 {
@@ -36,10 +41,24 @@ void setup_search_cont()
 	::shapes = shape_config(index_mode, 1, vector<string>());
 }
 
+bool use_single_indexed(double coverage, size_t query_letters, size_t ref_letters)
+{
+	if (coverage >= SINGLE_INDEXED_SEED_SPACE_MAX_COVERAGE)
+		return false;
+	if (config.mode_more_sensitive || config.mode_sensitive) {
+		return query_letters < 300000llu && query_letters * 20000llu < ref_letters;
+	}
+	else
+		return query_letters < 3000000llu && query_letters * 2000llu < ref_letters;
+}
+
 void setup_search()
 {
 	if (config.algo == Config::double_indexed) {
-		if (config.mode_more_sensitive) {
+		if (config.mode_very_sensitive) {
+			Config::set_option(config.index_mode, 4u);
+			Config::set_option(config.freq_sd, 200.0);
+		} else if (config.mode_more_sensitive) {
 			Config::set_option(config.index_mode, 9u);
 			Config::set_option(config.freq_sd, 200.0);
 		}
@@ -67,6 +86,8 @@ void setup_search()
 		config.lowmem = 1;
 	}
 
+	SeedComplexity::init(Reduction::reduction);
+
 	message_stream << "Algorithm: " << (config.algo == Config::double_indexed ? "Double-indexed" : "Query-indexed") << endl;
 	verbose_stream << "Reduction: " << Reduction::reduction << endl;
 
@@ -77,7 +98,7 @@ void setup_search()
 
 void setup_search_params(pair<size_t, size_t> query_len_bounds, size_t chunk_db_letters)
 {
-	const double b = config.min_bit_score == 0 ? score_matrix.bitscore(config.max_evalue, ref_header.letters, (unsigned)query_len_bounds.first) : config.min_bit_score;
+	const double b = config.min_bit_score == 0 ? score_matrix.bitscore(config.max_evalue, (unsigned)query_len_bounds.first) : config.min_bit_score;
 
 	if (config.mode_very_sensitive) {
 		Reduction::reduction = Reduction("A KR EDNQ C G H ILVM FYW P ST"); // murphy.10
