@@ -22,8 +22,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <vector>
 #include <exception>
 #include "../basic/config.h"
-#include "temp_file.h"
+#include "io/temp_file.h"
+#include "io/input_file.h"
 #include "log_stream.h"
+#include "../util/ptr_vector.h"
 
 using std::vector;
 using std::string;
@@ -44,7 +46,7 @@ struct Async_buffer
 		log_stream << "Async_buffer() " << input_count << ',' << bin_size_ << endl;
 		for (unsigned j = 0; j < config.threads_; ++j)
 			for (unsigned i = 0; i < bins; ++i) {
-				tmp_file_.push_back(Temp_file());
+				tmp_file_.push_back(new TempFile());
 				size_.push_back(0);
 			}
 	}
@@ -61,7 +63,7 @@ struct Async_buffer
 
 	struct Iterator
 	{
-		Iterator(Async_buffer &parent, unsigned thread_num) :
+		Iterator(Async_buffer &parent, size_t thread_num) :
 			buffer_(parent.bins()),
 			parent_(parent),
 			thread_num_(thread_num)
@@ -91,9 +93,9 @@ struct Async_buffer
 	private:
 		enum { buffer_size = 65536 };
 		vector<vector<_t> > buffer_;
-		vector<Temp_file*> out_;
+		vector<TempFile*> out_;
 		Async_buffer &parent_;
-		const unsigned thread_num_;
+		const size_t thread_num_;
 	};
 
 	size_t load(vector<_t> &data, size_t max_size, std::pair<size_t,size_t> &input_range)
@@ -131,7 +133,7 @@ private:
 	void load_bin(_t*& ptr, size_t bin)
 	{
 		for (unsigned i = 0; i < config.threads_; ++i) {
-			Input_stream f(tmp_file_[i*bins_ + bin]);
+			InputFile f(tmp_file_[i*bins_ + bin]);
 			const size_t s = size_[i*bins_ + bin];
 			const size_t n = f.read(ptr, s);
 			ptr += s;
@@ -149,12 +151,12 @@ private:
 		return size;
 	}
 
-	Temp_file* get_out(unsigned threadid, unsigned bin)
+	TempFile* get_out(size_t threadid, unsigned bin)
 	{
 		return &tmp_file_[threadid*bins_ + bin];
 	}
 
-	void add_size(unsigned thread_id, unsigned bin, size_t n)
+	void add_size(size_t thread_id, unsigned bin, size_t n)
 	{
 		size_[thread_id*bins_ + bin] += n;
 	}
@@ -163,7 +165,7 @@ private:
 	const size_t bin_size_, input_count_;
 	size_t bins_processed_;
 	vector<size_t> size_;
-	vector<Temp_file> tmp_file_;
+	PtrVector<TempFile> tmp_file_;
 
 };
 
