@@ -24,14 +24,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 using std::vector;
 
 template<typename _t>
-struct Ptr_vector : public vector<_t*>
+struct PtrVector : public vector<_t*>
 {
 
-	Ptr_vector():
+	PtrVector():
 		vector<_t*>()
 	{}
 	
-	Ptr_vector(typename vector<_t*>::size_type n):
+	PtrVector(typename vector<_t*>::size_type n):
 		vector<_t*>(n)
 	{}
 
@@ -46,6 +46,11 @@ struct Ptr_vector : public vector<_t*>
 		return vector<_t*>::operator[](n);
 	}
 
+	_t& back()
+	{
+		return *vector<_t*>::back();
+	}
+
 	typename vector<_t*>::iterator erase(typename vector<_t*>::iterator first, typename vector<_t*>::iterator last)
 	{
 		for (typename vector<_t*>::iterator i = first; i < last; ++i)
@@ -53,10 +58,16 @@ struct Ptr_vector : public vector<_t*>
 		return vector<_t*>::erase(first, last);
 	}
 
-	~Ptr_vector()
+	void clear()
 	{
-		for(typename vector<_t*>::iterator i=this->begin(); i!=this->end(); ++i)
+		for (typename vector<_t*>::iterator i = this->begin(); i != this->end(); ++i)
 			delete *i;
+		vector<_t*>::clear();
+	}
+
+	~PtrVector()
+	{
+		clear();
 	}
 
 };
