@@ -40,13 +40,14 @@ void copy_line(const string & s, vector<_t>& v, size_t d, _what)
 		v.push_back(convert_char<_what>(*i));
 }
 
-bool FASTA_format::get_seq(vector<char>& id, vector<Letter>& seq, Input_stream & s) const
+bool FASTA_format::get_seq(vector<char>& id, vector<Letter>& seq, TextInputFile & s) const
 {
+	// !!!
 	while (s.getline(), s.line.empty() && !s.eof());
 	if (s.eof())
 		return false;
 	if (s.line[0] != '>')
-		throw Stream_read_exception(s.line_count, "FASTA format error: Missing '>' at record start.");
+		throw StreamReadException(s.line_count, "FASTA format error: Missing '>' at record start.");
 	id.clear();
 	seq.clear();
 	copy_line(s.line, id, 1, Raw_text());
@@ -66,19 +67,19 @@ bool FASTA_format::get_seq(vector<char>& id, vector<Letter>& seq, Input_stream &
 			copy_line(s.line, seq, 0, Sequence_data());
 		}
 		catch (invalid_sequence_char_exception &e) {
-			throw Stream_read_exception(s.line_count, e.what());
+			throw StreamReadException(s.line_count, e.what());
 		}
 	}
 	return true;
 }
 
-bool FASTQ_format::get_seq(vector<char>& id, vector<Letter>& seq, Input_stream & s) const
+bool FASTQ_format::get_seq(vector<char>& id, vector<Letter>& seq, TextInputFile & s) const
 {
 	while (s.getline(), s.line.empty() && !s.eof());
 	if (s.eof())
 		return false;
 	if (s.line[0] != '@')
-		throw Stream_read_exception(s.line_count, "FASTQ format error: Missing '@' at record start.");
+		throw StreamReadException(s.line_count, "FASTQ format error: Missing '@' at record start.");
 	id.clear();
 	seq.clear();
 	copy_line(s.line, id, 1, Raw_text());
@@ -87,16 +88,16 @@ bool FASTQ_format::get_seq(vector<char>& id, vector<Letter>& seq, Input_stream &
 		copy_line(s.line, seq, 0, Sequence_data());
 	}
 	catch (invalid_sequence_char_exception &e) {
-		throw Stream_read_exception(s.line_count, e.what());
+		throw StreamReadException(s.line_count, e.what());
 	}
 	s.getline();
 	if (s.line.empty() || s.line[0] != '+')
-		throw Stream_read_exception(s.line_count, "FASTQ format error: Missing '+' line in record.");
+		throw StreamReadException(s.line_count, "FASTQ format error: Missing '+' line in record.");
 	s.getline();
 	return true;
 }
 
-const Sequence_file_format * guess_format(Input_stream &file)
+const Sequence_file_format * guess_format(TextInputFile &file)
 {
 	static const FASTA_format fasta;
 	static const FASTQ_format fastq;
