@@ -24,7 +24,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <stdexcept>
 #include <stdint.h>
 #include <limits>
+#include <vector>
 #include "util.h"
+#include "algo/varint.h"
+
+using std::vector;
 
 struct TextBuffer
 {
@@ -33,7 +37,8 @@ struct TextBuffer
 		data_ (0),
 		ptr_ (data_),
 		alloc_size_(0)
-	{ }
+	{
+	}
 
 	~TextBuffer()
 	{
@@ -43,6 +48,8 @@ struct TextBuffer
 	void reserve(size_t n)
 	{
 		const size_t s = ptr_ - data_;
+		if (s + n < alloc_size_)
+			return;
 		alloc_size_ = s + n + block_size - ((s + n) & (block_size - 1));
 		data_ = (char*)realloc(data_, alloc_size_);
 		ptr_ = data_ + s;
@@ -111,23 +118,7 @@ struct TextBuffer
 
 	TextBuffer& write_varint(unsigned x)
 	{
-		if (x < 1 << 7) {
-			write((uint8_t)(x << 1 | 1));
-		}
-		else if (x < 1 << 14) {
-			write((uint16_t)(x << 2 | 2));
-		}
-		else if (x < 1 << 21) {
-			write(uint8_t((x & 31) << 3 | 4));
-			write(uint16_t(x >> 5));
-		}
-		else if (x < 1 << 28) {
-			write(uint32_t(x << 4 | 8));
-		}
-		else {
-			write(uint8_t((x & 7) << 5 | 16));
-			write(uint32_t(x >> 3));
-		}
+		::write_varint(x, *this);
 		return *this;
 	}
 
@@ -227,6 +218,16 @@ struct TextBuffer
 		return *this;
 	}
 
+	TextBuffer& print(const vector<unsigned> &v, char separator)
+	{
+		if (v.empty()) return *this;
+		vector<unsigned>::const_iterator i = v.begin();
+		*this << *(i++);
+		for (; i < v.end(); ++i)
+			*this << ';' << *i;
+		return *this;
+	}
+
 	/*Text_buffer& operator<<(uint8_t x)
 	{
 		write(x);
