@@ -1,6 +1,6 @@
 /****
 DIAMOND protein aligner
-Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
+Copyright (C) 2013-2018 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
@@ -21,21 +21,22 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <vector>
 #include <algorithm>
-#include <sstream>
 #include <iostream>
 #include <string.h>
-#include <sys/stat.h>
 #include <math.h>
 #include <ctype.h>
 #include <string>
 #include <limits>
 #include <stdexcept>
+#include <stdio.h>
+#include <stdint.h>
+#include <set>
 #include "simd.h"
 #include "../basic/const.h"
-#include "../basic/packed_loc.h"
 
 using std::vector;
 using std::string;
+using std::set;
 
 template<typename _t=size_t>
 struct partition
@@ -144,9 +145,9 @@ inline size_t find_first_of(const char *s, const char *delimiters)
 	return t-s;
 }
 
-inline string get_title(const string &s)
+inline string blast_id(const string &title)
 {
-	return s.substr(0, find_first_of(s.c_str(), Const::id_delimiters));
+	return title.substr(0, find_first_of(title.c_str(), Const::id_delimiters));
 }
 
 inline void get_title_def(const string &s, string &title, string &def)
@@ -198,16 +199,6 @@ inline void auto_append_extension(string &str, const char *ext)
 		str += ext;
 }
 
-inline bool check_dir(const string &path)
-{
-#ifndef _MSC_VER
-	struct stat sb;
-	return stat(path.c_str(), &sb) == 0 && S_ISDIR(sb.st_mode);
-#else
-	return true;
-#endif
-}
-
 extern const char dir_separator;
 string extract_dir(const string &s);
 
@@ -387,22 +378,21 @@ bool equal(const _t *ptr, unsigned n)
 	return true;
 }
 
-template<typename _t>
-inline string to_string(_t val)
+inline string to_string(unsigned long long val)
 {
-	std::stringstream ss;
-	ss << val;
-	return ss.str();
+	char buf[32];
+	sprintf(buf, "%llu", val);
+	return string(buf);
 }
 
 inline string print_char(char c)
 {
-	std::stringstream ss;
+	char buf[16];
 	if (c < 32)
-		ss << "ASCII " << (unsigned)c;
+		sprintf(buf, "ASCII %u", (unsigned)c);
 	else
-		ss << c;
-	return ss.str();
+		sprintf(buf, "%c", c);
+	return string(buf);
 }
 
 template<typename _t, int n>
@@ -531,4 +521,23 @@ inline uint64_t next_power_of_2(double x)
 	return 1llu << uint64_t(ceil(log(x) / log(2)));
 }
 
+inline string hex_print(const char *x, int len) {
+	string out;
+	char d[3];
+	for (int i = 0; i < len; i++) {
+		sprintf(d, "%02x", (unsigned char)x[i]);
+		out += d;
+	}
+	return out;
+}
+
+inline set<unsigned> parse_csv(const string &s)
+{
+	set<unsigned> r;
+	vector<string> t(tokenize(s.c_str(), ","));
+	for (vector<string>::const_iterator i = t.begin(); i != t.end(); ++i)
+		if(!i->empty()) r.insert(atoi(i->c_str()));
+	return r;
+}
+
 #endif /* UTIL_H_ */
